@@ -1,7 +1,7 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2011 by Moritz Onken.
+# This software is Copyright (c) 2012 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -9,8 +9,10 @@
 #
 package ElasticSearchX::Model::Document::Set;
 {
-  $ElasticSearchX::Model::Document::Set::VERSION = '0.0.4';
+  $ElasticSearchX::Model::Document::Set::VERSION = '0.0.5';
 }
+
+# ABSTRACT: Represents a query used for fetching a set of results
 use Moose;
 use MooseX::ChainedAccessors;
 use ElasticSearchX::Model::Scroll;
@@ -41,12 +43,6 @@ has [qw(fields sort)] => (
 
 sub add_sort { push( @{ $_[0]->sort }, $_[1] ); return $_[0]; }
 
-has fields => (
-    isa    => 'ArrayRef',
-    is     => 'rw',
-    traits => [qw(Chained)]
-);
-
 sub add_field { push( @{ $_[0]->fields }, $_[1] ); return $_[0]; }
 
 has query_type => ( isa => QueryType, is => 'rw', traits => [qw(Chained)] );
@@ -100,8 +96,9 @@ sub inflate_result {
     my $parent = $type->get_parent_attribute;
     return $type->new_object(
         {   %{ $res->{_source} || {} },
-            index => $index,
-            _id   => $res->{_id},
+            index    => $index,
+            _id      => $res->{_id},
+            _version => $res->{_version},
             $id     ? ( $id->name     => $res->{_id} )     : (),
             $parent ? ( $parent->name => $res->{_parent} ) : (),
         }
@@ -109,7 +106,7 @@ sub inflate_result {
 }
 
 sub get {
-    my ( $self, $args ) = @_;
+    my ( $self, $args, $qs ) = @_;
     my ($id);
     my ( $index, $type ) = ( $self->index->name, $self->type->short_name );
 
@@ -132,25 +129,26 @@ sub get {
         );
     }
 
-    my $res = eval {
-        $self->es->transport->request(
-            {   method => 'GET',
-                cmd    => "/$index/$type/$id"
-            }
-        );
-    };
+    my $res = $self->es->get(
+        index => $index,
+        type  => $type,
+        id    => $id,
+        $self->fields ? ( fields => $self->fields ) : (),
+        ignore_missing => 1,
+        %{ $qs || {} },
+    );
     return undef unless ($res);
     return $self->inflate ? $self->inflate_result($res) : $res;
 }
 
 sub all {
-    my $self = shift;
+    my ( $self, $qs ) = @_;
     my ( $index, $type ) = ( $self->index->name, $self->type->short_name );
     my $res = $self->es->transport->request(
         {   method => 'POST',
             cmd    => "/$index/$type/_search",
             data   => $self->_build_query,
-            qs     => { version => 1 }
+            qs     => { version => 1, %{ $qs || {} } },
         }
     );
     return $res unless ( $self->inflate );
@@ -159,8 +157,8 @@ sub all {
 }
 
 sub first {
-    my $self = shift;
-    my @data = $self->size(1)->all;
+    my ( $self, $qs ) = @_;
+    my @data = $self->size(1)->all($qs);
     return undef unless (@data);
     return $data[0] if ( $self->inflate );
     return $data[0]->{hits}->{hits}->[0];
@@ -178,11 +176,23 @@ sub count {
     return $res->{hits}->{total};
 }
 
+sub delete {
+    my ( $self, $qs ) = @_;
+    my $query = $self->_build_query;
+    return $self->es->delete_by_query(
+        index => $self->index->name,
+        type  => $self->type->short_name,
+        query => $query->{filter} ? { filtered => $query } : $query->{query},
+        %{ $qs || {} },
+    );
+}
+
 sub scroll {
-    my ( $self, $scroll ) = @_;
+    my ( $self, $scroll, $qs ) = @_;
     return ElasticSearchX::Model::Scroll->new(
         set => $self,
-        scroll => $scroll || '1m'
+        scroll => $scroll || '1m',
+        qs => { version => 1, %{ $qs || {} } },
     );
 }
 
@@ -194,11 +204,11 @@ __END__
 
 =head1 NAME
 
-ElasticSearchX::Model::Document::Set
+ElasticSearchX::Model::Document::Set - Represents a query used for fetching a set of results
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -272,7 +282,7 @@ the attributes.
 =head2 inflate
 
 Inflate the returned results to the appropriate document
-object. Defaults to C<1>. You can either use C<$type->inflate(0)>
+object. Defaults to C<1>. You can either use C<< $type->inflate(0) >>
 to disable this behaviour for extra speed, or you can
 use the L</raw> convenience method.
 
@@ -284,10 +294,32 @@ use the L</raw> convenience method.
 
 =head2 all
 
+=head2 all( { %qs } )
+
 Returns all results as a list, limited by L</size> and L</from>.
 
+=head2 scroll
+
+=head2 scroll( $scroll, { %qs } )
+
+ my $iterator = $twitter->type('tweet')->scroll;
+ while ( my $tweet = $iterator->next ) {
+     # do something
+ }
+
+Large results should be scrolled thorugh using this iterator.
+It will return an instance of L<ElasticSearchX::Model::Scroll>.
+The C<$scroll> parameter is a time value parameter (for example: C<5m>),
+indicating for how long the nodes that participate in the search will
+maintain relevant resources in order to continue and support it.
+C<$scroll> defaults to C<1m>.
+
+Scrolling is executed by pulling in L</size> number of documents.
+
 =head2 first
 
+=head2 first( { %qs } )
+
 Returns the first result only. It automatically sets
 L</size> to C<1> to speed up the retrieval. However,
 it doesn't touch L</from>. In order to get the second
@@ -299,8 +331,17 @@ result, you would do:
 
 Returns the number of results.
 
+=head2 delete
+
+=head2 delete( { %qs } )
+
+Delete all documents that match the query. Issues a call to
+L<ElasticSearch/delete_by_query()>.
+
 =head2 get
 
+=head2 get( { %qs } )
+
  $type->get('fd_ZGWupT2KOxw3w9Q7VSA');
  
  $type->get({
@@ -314,6 +355,8 @@ the values that make up the id.
 
 =head2 put
 
+=head2 put( { %qs } )
+
  my $doc = $type->put({
      message => 'hello',
  });
@@ -345,7 +388,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Moritz Onken.
+This software is Copyright (c) 2012 by Moritz Onken.
 
 This is free software, licensed under:
 
