@@ -1,7 +1,7 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2011 by Moritz Onken.
+# This software is Copyright (c) 2012 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -9,14 +9,16 @@
 #
 package ElasticSearchX::Model::Document::Trait::Class;
 {
-  $ElasticSearchX::Model::Document::Trait::Class::VERSION = '0.0.4';
+  $ElasticSearchX::Model::Document::Trait::Class::VERSION = '0.0.5';
 }
+
+# ABSTRACT: Trait that extends the meta class of a document class
 use Moose::Role;
 use List::Util ();
 use Carp;
 
-has bulk_size => ( isa => 'Int', default => 10, is => 'rw' );
-has set_class => ( is => 'ro', builder => '_build_set_class', lazy => 1 );
+has set_class  => ( is => 'ro', builder => '_build_set_class',  lazy => 1 );
+has short_name => ( is => 'ro', builder => '_build_short_name', lazy => 1 );
 has _all_properties =>
     ( is => 'ro', lazy => 1, builder => '_build_all_properties' );
 
@@ -27,10 +29,6 @@ sub _build_set_class {
         or return 'ElasticSearchX::Model::Document::Set';
 }
 
-sub bulk_commit {
-
-}
-
 sub mapping {
     my $self  = shift;
     my $props = {
@@ -48,7 +46,7 @@ sub mapping {
     };
 }
 
-sub short_name {
+sub _build_short_name {
     my $self = shift;
     ( my $name = $self->name ) =~ s/^.*:://;
     return lc($name);
@@ -68,6 +66,10 @@ sub get_parent_attribute {
     return $id;
 }
 
+sub get_version_attribute {
+    shift->get_attribute('_version');
+}
+
 sub get_all_properties {
     my $self = shift;
     return @{ $self->_all_properties }
@@ -82,23 +84,6 @@ sub _build_all_properties {
     ];
 }
 
-sub put_mapping {
-    my ( $self, $es ) = @_;
-    $es->put_mapping( $self->mapping );
-}
-
-sub bulk_index {
-    my ( $self, $es, $bulk, $force ) = @_;
-    while ( @$bulk > $self->bulk_size || $force ) {
-        my @step = splice( @$bulk, 0, $self->bulk_size );
-        my @data = map { { create => { $_->_index } } }
-            map { $self->name->new(%$_) } @step;
-
-        $es->bulk(@data);
-        undef $force unless (@$bulk);
-    }
-}
-
 sub get_data {
     my ( $self, $instance ) = @_;
     return {
@@ -112,16 +97,72 @@ sub get_data {
 
 1;
 
+
 __END__
 =pod
 
 =head1 NAME
 
-ElasticSearchX::Model::Document::Trait::Class
+ElasticSearchX::Model::Document::Trait::Class - Trait that extends the meta class of a document class
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
+
+=head1 ATTRIBUTES
+
+=head2 set_class
+
+A call to C<< $index->type('tweet') >> returns an instance of C<set_class>. Given a
+document class C<MyModel::Tweet>, the builder of this attribute tries to find a
+class named C<MyModel::Tweet::Set>. If it's not found, the default class
+L<ElasticSearchX::Model::Document::Set> is used.
+
+A custum set class (e.g. C<MyModel::Tweet::Set>) B<must> inherit from
+L<ElasticSearchX::Model::Document::Set>.
+
+=head2 short_name
+
+ MyClass::Tweet->meta->short_name; # tweet
+
+The C<short_name> is used as name for the type. It defaults to the lowercased,
+last segment of the class name.
+
+=head1 METHODS
+
+=head2 mapping
+
+  my $mapping = $document->meta->mapping;
+
+Builds the type mapping for this document class. It loads all properties
+using L</get_all_properties> and calls
+L<ElasticSearchX::Model::Document::Trait::Attribute/build_property>.
+
+=head2 get_id_attribute
+
+Get the C<id> attribute, i.e. the attribute that has the C<id> option
+set. Returns undef if it doesn't exist.
+
+=head2 get_parent_attribute
+
+Get the C<parent> attribute, i.e. the attribute that has the C<parent> option
+set. Returns undef if it doesn't exist.
+
+=head2 get_all_properties
+
+Returns a list of all properties in the document class. An attribute is considered
+a property, if it I<does> the L<ElasticSearchX::Model::Document::Trait::Attribute>
+role. That means all attributes that don't have the C<property> option explicitly
+set to C<0>.
+
+Since this method is called quite often, the result is cached if the document class
+is immutable.
+
+=head2 get_data
+
+L<ElasticSearchX::Model::Document/put> calls this method to get an HashRef of
+all properties and their values. Values are deflated if a deflator was specified
+(e.g. L<DateTime> objects are deflated to an ISO8601 string).
 
 =head1 AUTHOR
 
@@ -129,7 +170,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by Moritz Onken.
+This software is Copyright (c) 2012 by Moritz Onken.
 
 This is free software, licensed under:
 
